#
# spec file for package pam_ssh_agent_auth
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


%{!?_pam_moduledir: %define _pam_moduledir /%{_lib}/security}

Name:           pam_ssh_agent_auth
Version:        0.10.4
Release:        3.2
Summary:        Permits PAM authentication via your keyring in a forwarded ssh-agent
License:        OpenSSL
Group:          Development/Tools/Other
URL:            https://github.com/FlorianFranzen/pam_ssh_agent_auth
Source:         %{name}-%{version}.tar.gz
### 20241107: having issues compiling with gcc14, but this patch helps
Patch0:         gcc14-configure.patch
Patch1:         dot-c.patch
Patch2:         bsd-misc.patch
#BuildRequires:  gcc13
#####
BuildRequires:  git-core
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
BuildRequires:  perl
BuildRequires:  sed

%description
pam_ssh_agent_auth is a PAM module which permits PAM
authentication via your keyring in a forwarded ssh-agent.

20220111: using https://github.com/FlorianFranzen/pam_ssh_agent_auth,
"just-one-big-cookie" branch so that ed25519 + Yubikey works.

%prep
%setup -q -n %{name}-%{version}
### 20241107: for gcc14
%patch -p1 -P 0
%patch -P 1
%patch -P 2
#####

%build
### 20241107: won't be required for gcc14
#export CC=gcc-13
#####
# 'git submodule init; git submodule update'
#   required before being tar'd up.
%configure \
  --without-openssl-header-check \
  --with-mantype=man \
  --libexecdir=%{_pam_moduledir}
%make_build

%install
%make_install

%files
%doc README
%license LICENSE.OpenSSL
%{_mandir}/man8/%{name}.8.gz
%{_pam_moduledir}/pam_ssh_agent_auth.so

%changelog
* Thu Nov  7 2024 Scott Bradnick <scott.bradnick@suse.com>
- Adding the following patches:
  * bsd-misc.patch -> address "duplicate __progname" issue
  * dot-c.patch -> this is basically '1000-gcc-14.patch' from Debian's patches
    for v0.10.3 via udd.debian.org
* Thu Nov  7 2024 Scott Bradnick <scott.bradnick@suse.com>
- Uncommenting out 'Patch0: gcc14-configure.patch' for factory-auto bot.
* Thu Nov  7 2024 Scott Bradnick <scott.bradnick@suse.com>
- Adding (disabled) 'gcc14-configure.patch' so gcc14 build issues can be
  partially addressed in the future; throws:
    "configure: error: *** compiler cannot create working executables,
    check config.log ***"
  otherwise.
  * More info here:
  - https://github.com/jbeverly/pam_ssh_agent_auth/issues/45
  - https://github.com/jbeverly/pam_ssh_agent_auth/issues/47
- Switching over to CC=gcc-13 until gcc14 builds can be fixed
* Tue Jan 11 2022 Scott Bradnick <scott.bradnick@suse.com>
- [Re-]Adding pam_ssh_agent_auth-0.10.4.tar.gz which was removed,
  repackaged and required.
* Tue Jan 11 2022 Scott Bradnick <scott.bradnick@suse.com>
- Switching to https://github.com/FlorianFranzen/pam_ssh_agent_auth,
  branch: "just-one-big-cookie" for ed25519 & Yubikey support.
* Tue Oct 19 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%_pam_moudledir - which was actually my recommendation.
- Pass --libexecdir=%%{_pam_moduledir} to configure as the
  build system very badly abused libexecdir for the install
  location.
* Mon Oct 18 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating spec file per @dimstar's recommendations.
* Sat Apr 17 2021 scott.bradnick@suse.com
- Update to version 0.10.4:
  * test pubkeys from SSH_AUTH_INFO_0 against authorized_keys. (#15)
  * Check against the correct OPENSSL_VERSION_NUMBER
  * Adapt to OpenSSL 1.1.1.
  * proc_pid_cmdline: fix type for feof(3)/fgetc(3)
  * authfd.c: check return value of seteuid(2)
  * Fix for release, and fix some review items.
  * ed25519 support
  * helps to actually add the implementation
  * initial support for ecdsa ssh keys
  * merging 0.10.2-rc1 into trunk
